@@ -18,7 +18,7 @@ LibraryItem* DS1307::libraryItem()
 {
     return new LibraryItem(
         "DS1307",
-        "Perifericals",
+        "Peripherals",
         "dsxxx_ico.png",
         "DS1307",
         DS1307::construct );
