@@ -100,11 +100,11 @@ void SR04::runEvent()
 {
     if( m_echouS )
     {
-        m_echo->sheduleState( true, 0 );
+        m_echo->scheduleState( true, 0 );
         Simulator::self()->addEvent( m_echouS*1e6, this ); // Event to finish echo
         m_echouS = 0;
     }
-    else m_echo->sheduleState( false, 0 );
+    else m_echo->scheduleState( false, 0 );
 }
 
 void SR04::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
