@@ -52,12 +52,12 @@ Hd44780::Hd44780( QObject* parent, QString type, QString id )
     }
     Simulator::self()->addToUpdateList( this );
     
-    initialize();
+    Hd44780::initialize();
 
     addPropGroup( { tr("Main"), {
-new IntProp <Hd44780>( "Rows" ,tr("Rows")   ,"_Rows"    ,this, &Hd44780::rows, &Hd44780::setRows ,"uint" ),
-new IntProp <Hd44780>( "Cols" ,tr("Columns"),"_Columns" ,this, &Hd44780::cols, &Hd44780::setCols ,"uint"  ),
-    }} );
+new IntProp <Hd44780>( "Rows" ,tr("Rows")   ,"_Rows"    ,this, &Hd44780::rows, &Hd44780::setRows ,0,"uint" ),
+new IntProp <Hd44780>( "Cols" ,tr("Columns"),"_Columns" ,this, &Hd44780::cols, &Hd44780::setCols ,0,"uint"  ),
+    }, groupNoCopy} );
 }
 Hd44780::~Hd44780(){}
 
